# =====================================
# generator=datazen
# version=3.2.1
# hash=751127fe6be569ca374f96d786047ad0
# =====================================

"""
Useful defaults and other package metadata.
"""

DESCRIPTION = "An interface generator for distributed computing."
PKG_NAME = "ifgen"
VERSION = "4.2.5"
